thermferm/pid.h

changeset 492
750f2468dec5
parent 363
468ec0d96cce
child 495
712984fdd26b
--- a/thermferm/pid.h	Sat Mar 05 12:50:23 2016 +0100
+++ b/thermferm/pid.h	Fri Mar 11 20:27:02 2016 +0100
@@ -21,7 +21,7 @@
 
 	double		Input;		/* Input value					*/
 	double		Err;		/* Error, diff between input and set point	*/
-	double		ErrLast;	/* Error from last pass				*/
+	double		InputLast;	/* Input from last pass				*/
 	double		iState;		/* Error from next last pass			*/
 	double		SetP;		/* Set point					*/
 	double		OutP;		/* Output of PID algorithm			*/

mercurial